@@ -536,7 +536,8 @@ def extra_subj_obj_nmod_propagation_of_nmods(sentence):
                 [Restriction(name="like", gov="case", form="like")],
                 [Restriction(name="such_as", gov="case", form="such", nested= [[
                     Restriction(gov="mwe", form="as")
-                ]])]
+                ]])],
+                [Restriction(name="including", gov="case", form="including")]
             ])
         ]])
     ]])
@@ -549,8 +550,8 @@ def extra_subj_obj_nmod_propagation_of_nmods(sentence):
         nmod, _, nmod_rel = name_space['nmod']
         receiver, _, _ = name_space['receiver']
         mediator_rel = name_space['mediator'][2]
-    
-        phrase = "like" if "like" in name_space else "such_as"
+        
+        phrase = [prep for prep in ["like", "such_as", "including"] if prep in name_space][0]
         nmod.add_edge(add_extra_info(split_by_at(mediator_rel)[0], "nmod", phrase=phrase, prevs=mediator_rel), receiver)
 
 
@@ -1566,7 +1567,6 @@ def convert_sentence(sentence, iids):
     extra_advcl_propagation(sentence, iids)
     extra_advcl_ambiguous_propagation(sentence, iids)
     extra_acl_propagation(sentence)
-    extra_amod_propagation(sentence)
     extra_dep_propagation(sentence, iids)
     extra_conj_propagation_of_nmods(sentence)
     extra_conj_propagation_of_poss(sentence)
@@ -1603,6 +1603,13 @@ def get_rel_set(converted_sentences):
     return set([(head.get_conllu_field("form"), rel, tok.get_conllu_field("form")) for sent in converted_sentences for tok in sent.values() for (head, rel) in tok.get_new_relations()])
 
 
+def on_last_iter_convs(sentence):
+    # TODO: after refactoring, if the match and replace system is more concise
+    #   maybe it would be better to simply check that the subject didnt cpme from an amod.
+    extra_amod_propagation(sentence)
+    return sentence
+
+
 def convert(parsed, enhanced, enhanced_plus_plus, enhanced_extra, conv_iterations, remove_enhanced_extra_info, remove_bart_extra_info, remove_node_adding_conversions, remove_unc, query_mode, funcs_to_cancel):
     global g_remove_enhanced_extra_info, g_remove_bart_extra_info, g_remove_node_adding_conversions
     g_remove_enhanced_extra_info = remove_enhanced_extra_info
@@ -1624,6 +1631,12 @@ def convert(parsed, enhanced, enhanced_plus_plus, enhanced_extra, conv_iteration
         if get_rel_set(converted_sentences) == last_converted_sentences:
             break
         i += 1
+
+    # here we run some conversions that we believe should run only once and after all other conversions
+    temp = []
+    for sent in converted_sentences:
+        temp.append(on_last_iter_convs(sent))
+    converted_sentences = temp
     
     funcs_to_cancel.restore_funcs()
     return converted_sentences, i
