@@ -1,9 +1,13 @@
+import struct
 from spacy.tokens import Doc, Token as SpacyToken
 from spacy import attrs
 import numpy as np
 
 from .graph_token import Token, add_basic_edges
 
+NUM_OF_BITS = struct.calcsize("P") * 8
+
+
 # this is here because it needs to happen only once (per import)
 SpacyToken.set_extension("parent_list", default=[])
 
@@ -30,7 +34,9 @@ def parse_spacy_sent(sent):
 
 
 def parse_bart_label(rel, is_state_head_node):
-    rel_l = rel.split("@")
+    # For the rare case which involvs a '@' preposition,
+    # we temporarily replace it with 'at', instead of simply doing rel.split("@")
+    rel_l = [x.replace(":at", ":@") for x in rel.replace(":@", ":at").split("@")]
     
     # defaults
     src = "UD" if not is_state_head_node else "BART"
@@ -41,7 +47,7 @@ def parse_bart_label(rel, is_state_head_node):
     if len(rel_l) > 1:
         # alternatives info
         if len(rel_l[1].split("#")) > 1:
-            alt = int(rel_l[1].split("#")[1])
+            alt = int(rel_l[1].split("#")[1].split("+")[0])
         # extra info
         src = rel_l[1].split("(")[0]
         extras = rel_l[1].split("(")[1].split(")")[0].split(", ")
@@ -75,7 +81,17 @@ def serialize_spacy_doc(orig_doc, converted_sentences):
         orig_attrs = orig.to_array(attrs_)
         
         # append copied attributes for new nodes
-        new_nodes_attrs = [orig_attrs[int(iid)] for iid, tok in converted.items() if int(iid) != iid]
+        new_nodes_attrs = []
+        for iid, tok in converted.items():
+            if int(iid) != iid:
+                new_node_attrs = list(orig_attrs[int(iid) - 1])
+                
+                # here we fix the relative head he is pointing to,
+                # in case it is a negative number we need to cast it to its unsigned synonym
+                relative = int(iid) - (len(orig_attrs) + len(new_nodes_attrs) + 1)
+                new_node_attrs[attrs_.index('HEAD')] = relative + (2**NUM_OF_BITS if relative < 0 else 0)
+                
+                new_nodes_attrs.append(new_node_attrs)
         if new_nodes_attrs:
             new_attrs = np.append(orig_attrs, new_nodes_attrs, axis=0)
         else:
@@ -102,14 +118,14 @@ def serialize_spacy_doc(orig_doc, converted_sentences):
         spacy_ids = {iid: (spacy_i + j) for spacy_i, iid in enumerate(converted.keys())}
         
         # set new info for all tokens per their head lists
-        for i, brat_tok in enumerate(converted.values()):
+        for i, bart_tok in enumerate(converted.values()):
             spacy_tok = new_doc[i + j]
-            for head, rel in brat_tok.get_new_relations():
+            for head, rel in bart_tok.get_new_relations():
                 # extract spacy correspondent head id
                 head_tok = new_doc[spacy_ids[head.get_conllu_field("id")] if head.get_conllu_field("id") != 0 else spacy_tok.i]
                 # parse stringish label
                 is_state_head_node = ((head_tok.text == "STATE") and (head.get_conllu_field("id") != int(head.get_conllu_field("id")))) or \
-                                     (brat_tok.get_conllu_field("id") != int(brat_tok.get_conllu_field("id")))
+                                     (bart_tok.get_conllu_field("id") != int(bart_tok.get_conllu_field("id")))
                 new_rel, src, unc, alt = parse_bart_label(rel, is_state_head_node=is_state_head_node)
                 # add info to token
                 spacy_tok._.parent_list.append({'head': head_tok, 'rel': new_rel, 'src': src, 'alt': alt, 'unc': unc})
